@@ -107,6 +107,7 @@ class Input(ScrollView):
             show=False,
         ),
         Binding("backspace", "delete_left", "Delete character left", show=False),
+        Binding("ctrl+shift+a", "select_all", "Select all", show=False),
         Binding("home,ctrl+a", "home", "Go to start", show=False),
         Binding("end,ctrl+e", "end", "Go to end", show=False),
         Binding("shift+home", "home(True)", "Select line start", show=False),
@@ -137,6 +138,7 @@ class Input(ScrollView):
     | ctrl+right | Move the cursor one word to the right. |
     | backspace | Delete the character to the left of the cursor. |
     | ctrl+shift+right | Move cursor right a word and select. |
+    | ctrl+shift+a | Select all text in the input. |
     | home,ctrl+a | Go to the beginning of the input. |
     | end,ctrl+e | Go to the end of the input. |
     | shift+home | Select up to the input start. |
@@ -690,7 +692,10 @@ class Input(ScrollView):
 
     def _toggle_cursor(self) -> None:
         """Toggle visibility of cursor."""
-        self._cursor_visible = not self._cursor_visible
+        if self.screen.is_active:
+            self._cursor_visible = not self._cursor_visible
+        else:
+            self._cursor_visible = True
 
     def _on_mount(self, event: Mount) -> None:
         def text_selection_started(screen: Screen) -> None:
@@ -870,6 +875,15 @@ class Input(ScrollView):
                 else:
                     self.cursor_position = max(start, end)
 
+    def select_all(self) -> None:
+        """Select all of the text in the Input."""
+        self.selection = Selection(0, len(self.value))
+        self._suggestion = ""
+
+    def action_select_all(self) -> None:
+        """Select all of the text in the Input."""
+        self.select_all()
+
     def action_home(self, select: bool = False) -> None:
         """Move the cursor to the start of the input.
 
